from datetime import datetime
from typing import List, Optional

from pydantic import BaseModel, Field

from app.models.order import OrderStatus


# Order Item Schemas
class OrderItemBase(BaseModel):
    product_id: int
    quantity: int = Field(..., gt=0)
    unit_price: float = Field(..., gt=0)

class OrderItemCreate(OrderItemBase):
    pass

class OrderItemInDBBase(OrderItemBase):
    id: int
    order_id: int
    created_at: datetime

    class Config:
        from_attributes = True

class OrderItem(OrderItemInDBBase):
    pass

# Order Schemas
class OrderBase(BaseModel):
    shipping_address: str
    status: Optional[OrderStatus] = OrderStatus.PENDING

class OrderCreate(OrderBase):
    pass

class OrderUpdate(BaseModel):
    status: Optional[OrderStatus] = None
    shipping_address: Optional[str] = None

class OrderInDBBase(OrderBase):
    id: int
    user_id: int
    total_amount: float
    created_at: datetime
    updated_at: Optional[datetime] = None
    status: OrderStatus

    class Config:
        from_attributes = True

class Order(OrderInDBBase):
    items: List[OrderItem]
